package tests;

import entities.onetomany.TheatreCompany;
import entities.onetomany.TheatreLocation;
import java.util.HashSet;
import java.util.Set;
import javax.persistence.EntityManager;
import javax.persistence.EntityManagerFactory;
import javax.persistence.Persistence;

public class TestsRunner {
    
    EntityManagerFactory emf = Persistence.createEntityManagerFactory("lazy-loading");
    private static long LOWES_ID = 678l;
    private static String LOWES_NAME = "LOWES";
    private static long NYC_ID = 44l;
    private static String NYC_CODE = "NYCNY";
    private static long ATLANTA_ID = 43l;
    private static String ATLANTA_CODE = "ATLGA";
    
    public static void main(String args[]){
        TestsRunner runner = new TestsRunner();
        runner.cascadePersistCompanyWithLocations();
        runner.findSavedCompany();
    }
    
    private void cascadePersistCompanyWithLocations() {
        EntityManager em = emf.createEntityManager();

        TheatreCompany lowes = createTheatreCompany(LOWES_ID, LOWES_NAME);
        TheatreLocation nyc = createTheatreLocation(NYC_ID, NYC_CODE);
        TheatreLocation atl = createTheatreLocation(ATLANTA_ID, ATLANTA_CODE);

        Set<TheatreLocation> locations = new HashSet();
        locations.add(nyc);
        locations.add(atl);
        
        lowes.setLocations(locations);
        nyc.setCompany(lowes);
        atl.setCompany(lowes);
        
        em.getTransaction().begin();
        em.persist(lowes);
        em.getTransaction().commit();
        em.close();
    }

    private void findSavedCompany() {
        EntityManager em = emf.createEntityManager();
        TheatreCompany found = em.find(TheatreCompany.class, LOWES_ID);
        
        System.out.print("No problem - " + found);
        em.close();
    }
    
    private TheatreLocation createTheatreLocation(long id, String code) {
        TheatreLocation loc = new TheatreLocation();
        loc.setId(id);
        loc.setCode(code);
        return loc;
    }
    
    private TheatreCompany createTheatreCompany(long id, String name) {
        TheatreCompany company = new TheatreCompany();
        company.setId(id);
        company.setName(name);
        return company;
    }

}
